@@ -1,3 +1,6 @@
+use strict;
+use warnings;
+
 =head1 NAME
 
 Win32::Process::Info::PT - Provide process information via Proc::ProcessTable.
@@ -28,15 +31,11 @@ only be called via that package.
 
 =head1 DESCRIPTION
 
-The main purpose of the Win32::Process::Info::PT package is to get
-whatever information is convenient (for the author!) about one or more
+The main purpose of the Win32::Process::Info package is to get whatever
+information is convenient (for the author!) about one or more
 processes. GetProcInfo (which see) is therefore the most-important
 method in the package. See it for more information.
 
-This package returns whatever process IDs are made available by
-Proc::ProcessTable. Under Cygwin, this seems to mean Cygwin process IDs,
-not Windows process IDs.
-
 Unless explicitly stated otherwise, modules, variables, and so
 on are considered private. That is, the author reserves the right
 to make arbitrary changes in the way they work, without telling
@@ -55,21 +54,12 @@ The following subroutines should be considered public:
 
 # 0.001	18-Sep-2007	T. R. Wyant
 #		Initial release.
-# 0.001_01 01-Apr-2009	T. R. Wyant
-#		Make Perl::Critic compliant (to -stern, with my own profile)
-# 0.002	02-Apr-2009	T. R. Wyant
-#		Production version.
-# 0.002_01 07-Apr-2009	T. R. Wyant
-#		Use $self->_build_hash(), so that we test it.
 
 package Win32::Process::Info::PT;
 
-use strict;
-use warnings;
-
-use base qw{ Win32::Process::Info };
-
-our $VERSION = '1.020_01';
+use base qw{Win32::Process::Info};
+use vars qw{$VERSION};
+$VERSION = '0.001';
 
 use Carp;
 use File::Basename;
@@ -179,31 +169,26 @@ to be consistent with the other variants.
 ##	utime => 'UserModeTime',
 	stime => sub {
 	    my ($info, $proc) = @_;
-	    $info->{KernelModeTime} = $proc->stime() * 10;
+	    $info->{KernelModeTime} = $proc->stime () * 10;
 	},
 	utime => sub {
 	    my ($info, $proc) = @_;
-	    $info->{UserModeTime} = $proc->utime() * 10;
+	    $info->{UserModeTime} = $proc->utime () * 10;
 	},
 	uid => sub {
 	    my ($info, $proc) = @_;
 	    $info->{OwnerSid} = my $uid = $proc->uid ();
-	    $info->{Owner} = $pw_uid{$uid} ||= '\\' . getpwuid($uid);
+	    $info->{Owner} = $pw_uid{$uid} ||= '\\' . getpwuid  ($uid);
 	},
     );
-    my @fld_sup = grep { defined $_ } Proc::ProcessTable->new ()->fields ();
+    my @fld_sup = Proc::ProcessTable->new ()->fields ();
 
     sub GetProcInfo {
-	my ($self, @args) = @_;
-
-	my $my_pid = $self->My_Pid();
-	my $opt = ref $args[0] eq 'HASH' ? shift @args : {};
+	my $self = shift;
+	my $opt = ref $_[0] eq 'HASH' ? shift : {};
 	my $tbl = Proc::ProcessTable->new ()->table ();
-
-	if (@args) {
-	    my %filter = map {
-		($_ eq '.' ? $my_pid : $_) => 1
-	    } @args;
+	if (@_) {
+	    my %filter = map {(($_ eq '.' ? $$ : $_), 1)} @_;
 	    $tbl = [grep {$filter{$_->pid ()}} @$tbl];
 	}
 	my @pinf;
@@ -214,11 +199,7 @@ to be consistent with the other variants.
 		if (ref $name eq 'CODE') {
 		    $name->($info, $proc);
 		} else {
-		    # Yes, we could just plop the information into the
-		    # hash. But _build_hash() needs to be called in
-		    # every variant so it gets tested under any
-		    # variant.
-		    $self->_build_hash($info, $name, $proc->$key());
+		    $info->{$name} = $proc->$key ();
 		}
 	    }
 	    push @pinf, $info;
@@ -238,16 +219,11 @@ reference to the list is returned.
 =cut
 
 sub ListPids {
-    my ($self, @args) = @_;
-
+    my $self = shift;
     my $tbl = Proc::ProcessTable->new ()->table ();
-    my $my_pid = $self->My_Pid();
     my @pids;
-
-    if (@args) {
-	my %filter = map {
-	    ($_ eq '.' ? $my_pid : $_) => 1
-	} @args;
+    if (@_) {
+	my %filter = map {(($_ eq '.' ? $$ : $_), 1)} @_;
 	@pids = grep {$filter{$_}} map {$_->pid} @$tbl;
     } else {
 	@pids = map {$_->pid} @$tbl;
@@ -255,10 +231,6 @@ sub ListPids {
     return wantarray ? @pids : \@pids;
 }
 
-sub My_Pid {
-    return $$;
-}
-
 =back
 
 =head1 REQUIREMENTS
@@ -287,20 +259,16 @@ both PPM and tar distributions.
 
 Thomas R. Wyant, III (F<wyant at cpan dot org>)
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT
 
-Copyright (C) 2007, 2009-2011, 2013-2014 by Thomas R. Wyant, III
+Copyright 2007 by Thomas R. Wyant, III. All rights reserved.
 
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl 5.10.0. For more details, see the full text
-of the licenses in the directory LICENSES.
+=head1 LICENSE
 
-This program is distributed in the hope that it will be useful, but
-without any warranty; without even the implied warranty of
-merchantability or fitness for a particular purpose.
+This module is free software; you can use it, redistribute it
+and/or modify it under the same terms as Perl itself. Please see
+L<http://perldoc.perl.org/index-licence.html> for the current licenses.
 
 =cut
 
-# ex: set textwidth=72 :
-
 1;
